@@ -321,7 +321,7 @@ func (info *Info) runInteractively() error {
 		doneChan <- err
 	}()
 
-	sig := make(chan os.Signal)
+	sig := make(chan os.Signal, 1)
 	signal.Notify(sig, syscall.SIGINT, syscall.SIGTERM)
 
 	var exitErr error
